@@ -166,18 +166,48 @@ function (model, custom_objects = NULL, compile = TRUE, safe_mode = TRUE)
 }
 
 
-#' Saves all layer weights to a `.weights.h5` file.
+#' Saves all weights to a single file or sharded files.
 #'
-#' @param model A keras Model object
+#' @description
+#' By default, the weights are saved in a single `.weights.h5` file. Enable
+#' sharding via `max_shard_size` to split weights across multiple files (in GB)
+#' and produce a `.weights.json` manifest that tracks shard metadata.
+#'
+#' The saved sharded files contain:
+#'
+#' * `*.weights.json`: configuration file containing `metadata` and
+#'   `weight_map` entries.
+#' * `*_xxxxxx.weights.h5`: weight shards limited by `max_shard_size`.
+#'
+#' ```{r}
+#' model <-
+#'   keras_model_sequential(input_shape = 2) |>
+#'   layer_dense(4)
+#'
+#' path_h5 <- tempfile(fileext = ".weights.h5")
+#' path_json <- tempfile(fileext = ".weights.json")
+#'
+#' model |> save_model_weights(path_h5)
+#' model |> save_model_weights(path_json, max_shard_size = 0.01)
+#'
+#' model |> load_model_weights(path_h5)
+#' model |> load_model_weights(path_json)
+#' ```
+#'
+#' @param model A keras Model object.
 #'
 #' @param filepath
-#' string.
-#' Path where to save the model. Must end in `.weights.h5`.
+#' Path where the weights will be saved. Accepts `.weights.h5`, or when sharding
+#' is enabled, a `.weights.json` manifest path. If `.weights.h5` is provided
+#' while sharding, the filename will be overridden to end in `.weights.json`.
 #'
 #' @param overwrite
-#' Whether we should overwrite any existing model
-#' at the target location, or instead ask the user
-#' via an interactive prompt.
+#' Whether to overwrite any existing weights at the target location, or instead
+#' ask the user via an interactive prompt.
+#'
+#' @param max_shard_size
+#' Numeric size in GB for each sharded file. Use `NULL` to disable sharding.
+#'
 #'
 #' @returns This is called primarily for side effects. `model` is returned,
 #'   invisibly, to enable usage with the pipe.
@@ -186,17 +216,21 @@ function (model, custom_objects = NULL, compile = TRUE, safe_mode = TRUE)
 #' @tether keras.Model.save_weights
 #' @seealso
 #' + <https://keras.io/api/models/model_saving_apis/weights_saving_and_loading#saveweights-method>
-#  + <https://www.tensorflow.org/api_docs/python/tf/keras/Model/save_weights>
 save_model_weights <-
-function (model, filepath, overwrite = FALSE)
+function (model, filepath, overwrite = FALSE, max_shard_size = NULL)
 {
     overwrite <- confirm_overwrite(filepath, overwrite)
-    keras$Model$save_weights(model, filepath, overwrite = overwrite)
+    keras$Model$save_weights(
+      model,
+      filepath,
+      overwrite = overwrite,
+      max_shard_size = max_shard_size
+    )
     invisible(model)
 }
 
 
-#' Load weights from a file saved via `save_model_weights()`.
+#' Load the weights from a single file or sharded files.
 #'
 #' @description
 #' Weights are loaded based on the network's
@@ -205,6 +239,12 @@ function (model, filepath, overwrite = FALSE)
 #' taken into account in the topological ordering, so adding or removing
 #' layers is fine as long as they don't have weights.
 #'
+#' **Sharding**
+#'
+#' When loading sharded weights, specify a `filepath` ending in
+#' `".weights.json"` (the configuration file), with the corresponding shard files
+#' (`*_xxxxx.weights.h5`) located alongside it.
+#'
 #' **Partial weight loading**
 #'
 #' If you have modified your model, for instance by adding a new layer
@@ -214,10 +254,16 @@ function (model, filepath, overwrite = FALSE)
 #' mismatching weights will be skipped. A warning will be displayed
 #' for each skipped layer.
 #'
+#' # Examples
+#' ```r
+#' model |> load_model_weights("model.weights.h5")
+#' model |> load_model_weights("model.weights.json")
+#' ```
+#'
 #' @param filepath
-#' String, path to the weights file to load.
-#' It can either be a `.weights.h5` file
-#' or a legacy `.h5` weights file.
+#' Path or path-like object to the weights. Accepts `.weights.h5`, legacy `.h5`,
+#' or sharded weights through a `.weights.json` manifest sitting alongside the
+#' shard files (`*_xxxxx.weights.h5`).
 #'
 #' @param skip_mismatch
 #' Boolean, whether to skip loading of layers where
@@ -519,7 +565,8 @@ function (object, filepath, call_endpoint = "serve", call_training_endpoint = NU
 #' # Note that `'my_package'` is used as the `package` argument here, and since
 #' # the `name` argument is not provided, `'MyDense'` is used as the `name`.
 #' layer_my_dense <- Layer("MyDense")
-#' register_keras_serializable(layer_my_dense, package = "my_package")
+#' layer_my_dense <-
+#'   register_keras_serializable(layer_my_dense, package = "my_package")
 #'
 #' MyDense <- environment(layer_my_dense)$`__class__` # the python class obj
 #' stopifnot(exprs = {
@@ -539,8 +586,8 @@ function (object, filepath, call_endpoint = "serve", call_training_endpoint = NU
 #' @param object
 #' A keras object.
 #'
-#' @returns `object` is returned invisibly, for convenient piping. This is
-#'   primarily called for side effects.
+#' @returns The registered `object` (and converted) is returned. This returned object is what you
+#' should must use when building and serializing the model.
 #' @export
 #' @family saving and loading functions
 #' @family serialization utilities
@@ -559,7 +606,18 @@ function (object, name = NULL, package = NULL)
                 c("", "base", "R_GlobalEnv"), "Custom")
 
   keras$saving$register_keras_serializable(package, name)(py_object)
-  invisible(object)
+  # Try to update a wrapper, e.g., returned by `Layer()`
+  if(is.function(object) && exists("__class__", env <- environment(object))) {
+    old_py_object <- get("__class__", env)
+    for(nm in names(env)) {
+      if(identical(get(nm, env), old_py_object))
+        assign(nm, py_object, env)
+    }
+    object
+  } else {
+    # return the registered py_object
+    py_object
+  }
 }
 
 
