@@ -11,6 +11,14 @@
 }
 
 
+#' @export
+Arg.keras.src.backend.common.keras_tensor.KerasTensor <- function(z) {
+  op_angle(z)
+}
+#' @export
+Arg.keras.src.backend.Tensor <- Arg.keras.src.backend.common.keras_tensor.KerasTensor
+
+
 
 #' @export
 as.array.keras.src.backend.common.variables.KerasVariable <- function(x, ...) {
@@ -102,4 +110,7 @@ py_to_r__keras.src.utils.tracking.TrackedSet <- function(x) import("builtins")$l
 # }
 # rm(list = c("generic", "cls"))
 
-
+#' @exportS3Method base::as.array
+as.array.PIL.Image.Image <- function(x, ...) {
+  as.array(image_to_array(x, ...))
+}
